aboutsummaryrefslogtreecommitdiffstats
path: root/eclipse/scripts
diff options
context:
space:
mode:
authorRaphael Moll <ralf@android.com>2013-04-17 14:01:13 -0700
committerRaphael Moll <ralf@android.com>2013-04-17 14:29:04 -0700
commitd995ff26d87f5a82d799657faca8de1167d39996 (patch)
treed64fe7216d794b1b0ffc8f1eb96f9b1d27e13f0c /eclipse/scripts
parentfa89a37dc29bb60f27820d81674ff547793b0a1a (diff)
downloadsdk-d995ff26d87f5a82d799657faca8de1167d39996.zip
sdk-d995ff26d87f5a82d799657faca8de1167d39996.tar.gz
sdk-d995ff26d87f5a82d799657faca8de1167d39996.tar.bz2
ADT preview qualifier.
The preview qualifier is toggled in the eclipse/script/build_server script. In preview mode, ADT will look like: adt.package_22.0.0.v201301020304-preview-1234567 In release moed, ADT will look like: adt.package_22.0.0.v201301020304-1234567 Change-Id: Ib332726854bf50f70de12fcf4bc157e358ba91a7
Diffstat (limited to 'eclipse/scripts')
-rwxr-xr-xeclipse/scripts/build_server.sh7
1 files changed, 4 insertions, 3 deletions
diff --git a/eclipse/scripts/build_server.sh b/eclipse/scripts/build_server.sh
index 4efd609..854e2b0 100755
--- a/eclipse/scripts/build_server.sh
+++ b/eclipse/scripts/build_server.sh
@@ -24,6 +24,7 @@ DEST_DIR=""
BUILD_NUMBER=""
CREATE_ZIP="1"
INTERNAL_BUILD=""
+PREVIEW="preview" # "preview" for preview builds, "" for final release builds.
function get_params() {
# parse input parameters
@@ -60,10 +61,10 @@ function check_params() {
[ -n "$DEST_DIR" ] || die "Usage: $0 <destination-directory> [build-number]"
[ -d "$DEST_DIR" ] || die "Destination directory $DEST_DIR must exist."
# Qualifier is "v" followed by date/time in YYYYMMDDHHSS format and the optional
# build number.
DATE=`date +v%Y%m%d%H%M`
- QUALIFIER="$DATE"
+ QUALIFIER="${DATE}-$PREVIEW"
[ -n "$BUILD_NUMBER" ] && QUALIFIER="${QUALIFIER}-${BUILD_NUMBER}"
return 0
@@ -60,10 +61,10 @@ function check_params() {
[ -n "$DEST_DIR" ] || die "Usage: $0 <destination-directory> [build-number]"
[ -d "$DEST_DIR" ] || die "Destination directory $DEST_DIR must exist."
- # Qualifier is "v" followed by date/time in YYYYMMDDHHSS format and the optional
- # build number.
+ # Qualifier is "v" followed by date/time in YYYYMMDDHHSS format, an optional "preview"
+ # tag and the optional build number.
DATE=`date +v%Y%m%d%H%M`